@@ -142,7 +142,8 @@ class StockMixin(object):
             }.get(operator_, lambda v, l: False)
         record_ids = []
         for key, quantity in pbl.items():
-            if operator_(quantity, operand):
+            if (quantity is not None and operand is not None
+                    and operator_(quantity, operand)):
                 # pbl could return None in some keys
                 if key[position] is not None:
                     record_ids.append(key[position])
@@ -245,6 +246,7 @@ class Move(Workflow, ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(Move, cls).__setup__()
+        cls.create_date.select = True
         cls._deny_modify_assigned = set(['product', 'uom', 'quantity',
             'from_location', 'to_location', 'company', 'currency'])
         cls._deny_modify_done_cancel = (cls._deny_modify_assigned |
@@ -320,9 +322,6 @@ class Move(Workflow, ModelSQL, ModelView):
         super(Move, cls).__register__(module_name)
         table = cls.__table_handler__(module_name)
 
-        # Add index on create_date
-        table.index_action('create_date', action='add')
-
         # Index for period join in compute_quantities_query
         table.index_action([
                 Coalesce(sql_table.effective_date,
